.. :changelog:

History
-------

0.0.1 (2017-10-13)
------------------

* First release
* Methods for Spotify API
* Slackclient wrapper

0.0.2 (2017-10-14)
------------------

* CLI draft
* Credentials parsing
* Minimal logic

0.0.3 (2017-10-14)
------------------

* Reaction name and reaction count configurable

0.0.4 (2017-10-26)
------------------

* Refactored SpotifyClient with objects and methods
* Refactored SlackSound interface

0.0.5 (2017-10-27)
------------------

* Entrypoint for main

0.1.0 (2017-10-27)
------------------

* Try a private channel first or fallback as a public one if fails

0.1.1 (2017-10-27)
------------------

* Logging for user
